funcc_show_bicluster_hscore: plotting hscore of each bi-cluster on bicluster dimension
Description
funcc_show_bicluster_hscore graphically shows the hscore vs the dimension (i.e. number of rows and columns) of each bi-cluster
Usage
funcc_show_bicluster_hscore(fun_mat, res_input)
Arguments
fun_mat
The data array (n x m x T) where each entry corresponds to the measure of one observation i, i=1,...,n, for a functional variable m, m=1,...,p, at point t, t=1,...,T
res_input
An object produced by the funcc_biclust function
Value
a figure representing the dimensions of each bi-cluster (i.e. number of rows and columns)
# NOT RUN {data("funCCdata")
res <- funcc_biclust(funCCdata,delta=10,theta=1,alpha=1,beta=0,const_alpha=TRUE)
funcc_show_bicluster_hscore(funCCdata,res)
# }